@@ -2,6 +2,10 @@ from .pinboard import Pinboard
 from .pinboard import Bookmark
 from .pinboard import Tag
 
+from .exceptions import PinboardAuthenticationError
+from .exceptions import PinboardForbiddenError
+from .exceptions import PinboardServerError
+
 from .metadata import (
     __author__,
     __copyright__,
@@ -18,6 +22,9 @@ __all__ = [
     '__license__',
     '__maintainer__',
     '__version__',
+    'PinboardAuthenticationError',
+    'PinboardForbiddenError',
+    'PinboardServerError',
     'Pinboard',
     'Bookmark',
     'Tag'
